==> haskell-hslua-module-system-0.2.2-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-system
version:              0.2.2
visibility:           public
id:                   hslua-module-system-0.2.2-5VxWgK9Rj0Q45GPdc3SX0B
key:                  hslua-module-system-0.2.2-5VxWgK9Rj0Q45GPdc3SX0B
license:              MIT
copyright:            © 2019-2020 Albert Krewinkel <albert+hslua@zeitkraut.de>
maintainer:           albert+hslua@zeitkraut.de
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua-module-system
synopsis:             Lua module wrapper around Haskell'\''s System module.
description:
    Provides access to system information and functionality
    to Lua scripts via Haskell'\''s `System` module.

    Intended usage for this package is to preload it by adding
    the loader function to `package.preload`. Note that the
    Lua `package` library must have already been loaded before
    the loader can be added.

category:             Foreign
abi:                  eca8727552c23bdbc9d1cf3578cc13f3
exposed:              True
exposed-modules:      Foreign.Lua.Module.System
hidden-modules:       Foreign.Lua.Module.SystemUtils
import-dirs:          /usr/lib/ghc-8.10.2/site-local/hslua-module-system-0.2.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/hslua-module-system-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/hslua-module-system-0.2.2

hs-libraries:         HShslua-module-system-0.2.2-5VxWgK9Rj0Q45GPdc3SX0B
depends:
    base-4.14.1.0 containers-0.6.2.1 directory-1.3.6.0
    exceptions-0.10.4 hslua-1.1.2-8jf3Sn02KHh2WBffNLx0YB
    temporary-1.3-CDcjaiJz2DxHviv15UVLr2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-system/html/hslua-module-system.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-system-0.2.2-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-system
version:              0.2.2
visibility:           public
id:                   hslua-module-system-0.2.2-ImvWXk3fRp67qgAKIOfzs0
key:                  hslua-module-system-0.2.2-ImvWXk3fRp67qgAKIOfzs0
license:              MIT
copyright:            © 2019-2020 Albert Krewinkel <albert+hslua@zeitkraut.de>
maintainer:           albert+hslua@zeitkraut.de
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua-module-system
synopsis:             Lua module wrapper around Haskell'\''s System module.
description:
    Provides access to system information and functionality
    to Lua scripts via Haskell'\''s `System` module.

    Intended usage for this package is to preload it by adding
    the loader function to `package.preload`. Note that the
    Lua `package` library must have already been loaded before
    the loader can be added.

category:             Foreign
abi:                  eae7fcc2152e04351e67a01ead3aeccf
exposed:              True
exposed-modules:      Foreign.Lua.Module.System
hidden-modules:       Foreign.Lua.Module.SystemUtils
import-dirs:          /usr/lib/ghc-8.10.2/site-local/hslua-module-system-0.2.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/hslua-module-system-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/hslua-module-system-0.2.2

hs-libraries:         HShslua-module-system-0.2.2-ImvWXk3fRp67qgAKIOfzs0
depends:
    base-4.14.1.0 containers-0.6.2.1 directory-1.3.6.0
    exceptions-0.10.4 hslua-1.1.2-EIbEvR5rt0RAFB79POwPUh
    temporary-1.3-GCrV1QxBo5I4IcfY3iupUZ

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-system/html/hslua-module-system.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
